@@ -7,7 +7,7 @@ use TheOneRing;
 
 our @ISA = qw(TheOneRing);
 
-our $VERSION = '0.22';
+our $VERSION = '0.3';
 
 sub init {
     my ($self) = @_;
@@ -28,12 +28,16 @@ sub init {
 	'args' => { m => '-m' },
        },
 
-#        'update' =>
-#        {
-# 	'args' => { r => '-r',
+        'update' =>
+        {
+	 'command' => 'pull',
+	 'options' => ['origin', 'HEAD'],
+ 	'args' => {
+#		    r => '-r',
 # 		    q => 'q',
-# 		    N => 'N'},
-#        },
+# 		    N => 'N',
+		  },
+	},
 
        # need a special function for this to deal with how revs are handled
        # ie, -r foo file => foo file
@@ -105,4 +109,9 @@ sub ignore {
     $self->add_to_file(".gitignore", @args);
 }
 
+sub move {
+    my ($self, @args) = @_;
+    $self->move_by_adddel(@args);
+}
+
 1;
